@@ -542,6 +542,13 @@ class ConfigBuilder(object):
                 return True
         return False
 
+    def _get_rfc8950_clients(self):
+        res = []
+        for client in self.cfg_clients.cfg["clients"]:
+            if client["cfg"]["rfc8950"]:
+                res.append(client["ip"])
+        return res
+
     def enrich_config(self):
         # Unique ASNs from clients list.
         clients_asns = {}
@@ -882,9 +889,9 @@ class BIRDConfigBuilder(ConfigBuilder):
 
     AVAILABLE_VERSION = ["1.6.3", "1.6.4", "1.6.6", "1.6.7", "1.6.8",
                          "2.0.7", "2.0.7+b962967e", "2.0.8", "2.0.9",
-                         "2.0.10", "2.0.11", "2.13", "2.14",
+                         "2.0.10", "2.0.11", "2.13", "2.14", "2.15",
                          "3.0"]
-    DEFAULT_VERSION = "2.14"
+    DEFAULT_VERSION = "2.15"
 
     def validate_bgpspeaker_specific_configuration(self):
         res = True
@@ -1023,6 +1030,18 @@ class BIRDConfigBuilder(ConfigBuilder):
                     ):
                         res = False
 
+        if version.parse(self.target_version) < version.parse("2.0"):
+            rfc8950_clients = self._get_rfc8950_clients()
+            cnt = len(rfc8950_clients)
+            if rfc8950_clients:
+                raise BuilderError(
+                    "RFC8950 is not supported on BIRD 1.x, but it is "
+                    "enabled for the following clients: {}{}.".format(
+                        ", ".join(rfc8950_clients[:3]),
+                        "" if cnt <= 3 else " and {} more".format(cnt - 3)
+                    )
+                )
+
         return res
 
     def _include_local_file(self, local_file_id):
@@ -1058,13 +1077,14 @@ class OpenBGPDConfigBuilder(ConfigBuilder):
     LOCAL_FILES_BASE_DIR = "/etc/bgpd"
 
     AVAILABLE_VERSION = ["7.0", "7.1", "7.2", "7.3", "7.4", "7.5", "7.6", "7.7",
-                         "7.8", "8.0", "8.3"]
+                         "7.8", "8.0", "8.3", "8.4"]
     DEFAULT_VERSION = AVAILABLE_VERSION[-1]
 
     IGNORABLE_ISSUES = ConfigBuilder.IGNORABLE_ISSUES + \
                         ["transit_free_action",
                         "add_path", "max_prefix_action",
                         "max_prefix_count_rejected_routes",
+                        "rfc8950",
                         "extended_communities",
                         "internal_communities",
                         "roles_discouraged"]
@@ -1157,6 +1177,19 @@ class OpenBGPDConfigBuilder(ConfigBuilder):
             ):
                 res = False
 
+        rfc8950_clients = self._get_rfc8950_clients()
+        if rfc8950_clients:
+            cnt = len(rfc8950_clients)
+            if not self.process_compatibility_issue(
+                "rfc8950",
+                "RFC8950 not supported by OpenBGPD but "
+                "enabled for the following clients: {}{}.".format(
+                    ", ".join(rfc8950_clients[:3]),
+                    "" if cnt <= 3 else " and {} more".format(cnt - 3)
+                )
+            ):
+                res = False
+
         if self.cfg_general["filtering"]["roles"]["enabled"]:
             if version.parse(self.target_version) < version.parse("7.5"):
                 if not self.process_compatibility_issue(
